@@ -3,7 +3,6 @@ import os
 import re
 import ssl
 import time
-from types import NoneType
 from xml.dom.minidom import Document
 import mechanize
 import requests
@@ -13,6 +12,7 @@ from kg_qa import VoIDAnalyses, aggregator,Graph
 from kg_qa.resources  import Resources
 from kg_qa import query as q
 import networkx as nx
+import pickle
 
 #PRINT THE METADATI OF A KG
 def printMetadatiKG(metadct):
@@ -164,13 +164,13 @@ def getResultsFromXML(results):
         literalList = results.getElementsByTagName('literal')
         numTags = results.getElementsByTagName("literal").length
         for i in range(numTags):
-            if (not isinstance(literalList[i].firstChild,NoneType)):
+            if literalList[i].firstChild is not None:
                 literal = literalList[i].firstChild.nodeValue
                 li.append(literal)
         literalList = results.getElementsByTagName('uri')
         numTags = results.getElementsByTagName("uri").length
         for i in range(numTags):
-            if (not isinstance(literalList[i].firstChild,NoneType)):
+            if literalList[i].firstChild is not None:
                 literal = literalList[i].firstChild.nodeValue
                 li.append(literal)
         return li
@@ -181,7 +181,7 @@ def getResultsFromXMLUri(results):
         literalList = results.getElementsByTagName('uri')
         numTags = results.getElementsByTagName("uri").length
         for i in range(numTags):
-            if (not isinstance(literalList[i].firstChild,NoneType)):
+            if literalList[i].firstChild is not None:
                 literal = literalList[i].firstChild.nodeValue
                 li.append(literal)
         return li
@@ -508,12 +508,12 @@ def getUrlVoID(otResources):
     if isinstance(otResources,list):
         for i in range(len(otResources)):
             resource = otResources[i]
-            if (not isinstance(resource.format,NoneType)):
+            if resource.format is not None:
                 if resource.format == 'meta/void' and resource.status == 'active':
                     urlV = resource.url
                     if isinstance(urlV,str):
                         return urlV
-                elif (not isinstance(resource.title,NoneType)):
+                elif resource.title is not None:
                     if 'void' in resource.title and resource.status == 'active':
                         urlV = resource.url
                         if isinstance(urlV,str):
@@ -816,11 +816,19 @@ def binarySearch(arr,l,r,x):
 def checkGraphFile():
     try: #CHECK IF THE FILE WITH THE GRAPH OF KNOWLEDGE GRAPH IS PRESENT
         here = os.path.dirname(os.path.abspath(__file__))
-        gFile = os.path.join(here,'GraphOfKG.gpickle')
-        graph = nx.read_gpickle(gFile)
+        gFile = os.path.join(here,'GraphOfKG.gpickle') #GET PATH OF CURRENT WORKING DIRECTORY
+        infile = open(gFile,'rb')
+        #graph = nx.read_gpickle(gFile)
+        graph = pickle.load(infile)
+        infile.close()
     except FileNotFoundError:   
         graph = Graph.buildGraph() #CREATION OF THE GRAPH OF KNOWLEDGE GRAPH
-        nx.write_gpickle(graph,'GraphOfKG.gpickle') #STORE IT ON DISK
+        here = os.path.dirname(os.path.abspath(__file__))
+        gFile = os.path.join(here,'GraphOfKG.gpickle') #GET PATH OF CURRENT WORKING DIRECTORY
+        outfile = open(gFile,'wb')
+        pickle.dump(graph,outfile) #STORE IT ON DISK
+        outfile.close()
+        #nx.write_gpickle(graph,'GraphOfKG.gpickle') #STORE IT ON DISK
     
     return graph
 
